; Copyright (c) 2004-2010, Stubbe F. Hviid
;   All rights reserved
;+
; NAME:
;   FUNCTION osiris_detect_saturation, header, image, quality_map
;
; PURPOSE:
;   Detect pixels where the CCD is non linear and saturated
;
; CATEGORY:
;   Osiris CCD Calibration
;
; CALLING SEQUENCE:
;  Result = osiris_detect_saturation(header, image, quality_map)
;
; INPUTS:
;   header:       PDS header structure of input image
;   image:      	The input image data in raw DN
;   quality_map:  Input quality map to be modified
;
; OUTPUTS:
;   quality_map:	output map of quality estimate for each pixel
;
; RETURNS:
;   0 on failure   1 on success
;
; RESTRICTIONS:
;   function requires that the paths defined in get_osiris_environment.pro has been set to correctly
;   point to the root directory of the external calibration files
;
; EXAMPLE:
;   p_read, pickfile(), h, d             ; read in raw PDS image
;   osiris_detect_saturation, h, d, quality_map
;
; MODIFICATION HISTORY:
;   Written by:  Stubbe F. Hviid   22/2-2010
;-

FUNCTION osiris_detect_saturation, header, image, quality_map

  if n_elements(image) eq 0 then return, 0

  sz = size(image, /dim)
  if n_elements(quality_map) eq 0 then quality_map = bytarr(sz[0], sz[1])

  ; define levels
  if p_value(header, 'SR_ACQUIRE_OPTIONS.GAIN_ID') eq 'HIGH' then begin
    saturation_level = 45000
    non_linear_level = 40000
  endif else begin
    saturation_level = 'FFFF'XL
    non_linear_level = 40000
  endelse

  ; get list of valid quality map values
  qmv = osiris_quality_values()

  ; detect non linear pixels
  s = where(image ge non_linear_level)
  if s[0] ne -1 then quality_map[s] = quality_map[s] OR qmv.non_linear_ccd

  ; detect saturated pixels
  s = where(image ge saturation_level)
  if s[0] ne -1 then quality_map[s] = quality_map[s] OR qmv.saturated_ccd

  ; register the level used in the historyt labels
  p_setvalue, header, 'LEVEL2_PIPELINE.NON_LINEARITY_LEVEL', non_linear_level, /GROUP, /HISTORY
  p_setvalue, header, 'LEVEL2_PIPELINE.SATURATION_LEVEL', saturation_level, /GROUP, /HISTORY


  return, 1
END