; Copyright (c) 2004, Stubbe F. Hviid
;   All rights reserved
;+
; NAME:
;   PRO osiris_model, header, camera, model
;
; PURPOSE:
;   Determine the camera and hardware model of an osiris image from the image header
;
; CATEGORY:
;   Osiris Calibration
;
; CALLING SEQUENCE:
;  osiris_model, header, camera, model
;
; INPUTS:
;   header:     The PDS image header of the image
;
; OUTPUTS:
;   camera:		The camera that was used to take the image (either NAC or WAC)
;               (The OSI part is discarded)
;               If no valid camera was found in header then camera will be "UNKNOWN"
;   model:		The hardware model (either EM, QM, FM, FS)
;               If no valid hardware model was found in header then model will be "UNKNOWN"
;
; EXAMPLE:
;   p_read, pickfile(), h, d             ; read in raw PDS image
;   osiris_model, h, camera, model
;   print, 'camera = ', camera
;   print, 'model  = ', model
;
; MODIFICATION HISTORY:
;   Written by:  Stubbe F. Hviid   28/6-2005
;-

PRO osiris_model, header, camera, model

	hcamera = p_value(header, 'INSTRUMENT_ID')

	if hcamera eq 'OSINAC' then begin
		camera = 'NAC'
	endif else if hcamera eq 'OSIWAC' then begin
		camera = 'WAC'
	endif else begin
		print, 'ERROR: Unknown camera detected in osiris_model'
		camera = 'UNKNOWN'
	endelse

	; determine hardware model
	if camera eq 'NAC' then begin
		model  = p_value(header, 'SR_HARDWARE_CONFIG.NAC_CAMERA_ID')
	endif else if camera eq 'WAC' then begin
		model  = p_value(header, 'SR_HARDWARE_CONFIG.WAC_CAMERA_ID')
	endif else begin
		print, 'ERROR: Unknown hardware model detected in osiris_model'
		model = 'UNKNOWN'
	endelse

	if model eq '' then begin
		print, 'ERROR: header did not contain valid OSIRIS hardware model information'
		model = 'UNKNOWN'
	endif

END